@@ -33,9 +33,10 @@
 #  define KDNSSD_DEPRECATED_NO_EXPORT KDNSSD_NO_EXPORT KDNSSD_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KDNSSD_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KDNSSD_NO_DEPRECATED
+#    define KDNSSD_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
